@@ -211,7 +211,7 @@ Return the list of bunsetsu."
   (let ((bunsetsu (car bunsetsu-list)))
 
     (unless (manabunsetsu-get-candidates bunsetsu)
-      (let* ((state (manabunsetsu-get-state bunsetsu))
+      (let* ((state (if prev-bunsetsu (manabunsetsu-get-state bunsetsu) 0))
 	     (source (manabunsetsu-get-source bunsetsu))
 	     (len (manabunsetsu-get-len bunsetsu))
 	     (cands (mana-list-candidates source state 0 len len)))
